==> ejc-probuilddiary-api-3.0.0-20220916.063707-4-sources.jar: com/ejianc/business/probuilddiary/person/vo/PersonDetailVO.java <==
package com.ejianc.business.probuilddiary.person.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 个人日志-施工内容（施工员）
 * 
 * @author generator
 * 
 */
public class PersonDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long personId; // 个人日志id
    private Long constructId; // 施工区域id
    private String constructName; // 施工区域名称
    private String constructCode; // 施工区域编码
    private Long teamId; // 施工区域id
    private String teamName; // 施工区域名称
    private String teamCode; // 施工区域编码
    private Integer workNum; // 工作人数
    private String workMemo; // 工作情况
    

    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    public Long getConstructId() {
        return constructId;
    }

    public void setConstructId(Long constructId) {
        this.constructId = constructId;
    }
    public String getConstructName() {
        return constructName;
    }

    public void setConstructName(String constructName) {
        this.constructName = constructName;
    }
    public String getConstructCode() {
        return constructCode;
    }

    public void setConstructCode(String constructCode) {
        this.constructCode = constructCode;
    }
    public Long getTeamId() {
        return teamId;
    }

    public void setTeamId(Long teamId) {
        this.teamId = teamId;
    }
    public String getTeamName() {
        return teamName;
    }

    public void setTeamName(String teamName) {
        this.teamName = teamName;
    }
    public String getTeamCode() {
        return teamCode;
    }

    public void setTeamCode(String teamCode) {
        this.teamCode = teamCode;
    }
    public Integer getWorkNum() {
        return workNum;
    }

    public void setWorkNum(Integer workNum) {
        this.workNum = workNum;
    }
    public String getWorkMemo() {
        return workMemo;
    }

    public void setWorkMemo(String workMemo) {
        this.workMemo = workMemo;
    }
    
}

==> ejc-probuilddiary-api-3.0.0-20220919.091701-11-sources.jar: com/ejianc/business/probuilddiary/person/vo/PersonDetailVO.java <==
package com.ejianc.business.probuilddiary.person.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 个人日志-施工内容（施工员）
 * 
 * @author generator
 * 
 */
public class PersonDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long personId; // 个人日志id
    private Long constructId; // 施工区域id
    private String constructName; // 施工区域名称
    private String constructCode; // 施工区域编码
    private Long teamId; // 班组id
    private String teamName; // 班组名称
    private String teamCode; // 班组编码
    private Integer workNum; // 工作人数
    private String workMemo; // 工作情况
    private String fileType; // 文件类型
    private String logNumber;//日志 数目

    public String getLogNumber() {
        return logNumber;
    }

    public void setLogNumber(String logNumber) {
        this.logNumber = logNumber;
    }

    public String getFileType() {
        return fileType;
    }

    public void setFileType(String fileType) {
        this.fileType = fileType;
    }

    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    public Long getConstructId() {
        return constructId;
    }

    public void setConstructId(Long constructId) {
        this.constructId = constructId;
    }
    public String getConstructName() {
        return constructName;
    }

    public void setConstructName(String constructName) {
        this.constructName = constructName;
    }
    public String getConstructCode() {
        return constructCode;
    }

    public void setConstructCode(String constructCode) {
        this.constructCode = constructCode;
    }
    public Long getTeamId() {
        return teamId;
    }
    @ReferDeserialTransfer
    public void setTeamId(Long teamId) {
        this.teamId = teamId;
    }
    public String getTeamName() {
        return teamName;
    }

    public void setTeamName(String teamName) {
        this.teamName = teamName;
    }
    public String getTeamCode() {
        return teamCode;
    }

    public void setTeamCode(String teamCode) {
        this.teamCode = teamCode;
    }
    public Integer getWorkNum() {
        return workNum;
    }

    public void setWorkNum(Integer workNum) {
        this.workNum = workNum;
    }
    public String getWorkMemo() {
        return workMemo;
    }

    public void setWorkMemo(String workMemo) {
        this.workMemo = workMemo;
    }
    
}
